Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(861)

Unified Diff: runtime/vm/isolate.h

Issue 800713002: - Implement Isolate.kill. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: runtime/vm/isolate.h
===================================================================
--- runtime/vm/isolate.h (revision 42195)
+++ runtime/vm/isolate.h (working copy)
@@ -362,8 +362,11 @@
return resume_request;
}
- // Verify that the sender has the capability to pause this isolate.
- bool VerifyPauseCapability(const Capability& capability) const;
+ // Verify that the sender has the capability to pause or terminate the
+ // isolate.
+ bool VerifyPauseCapability(const Object& capability) const;
+ bool VerifyTerminateCapability(const Object& capability) const;
siva 2014/12/13 00:24:05 Should there also be a VerifyPingCapability ?
Ivan Posva 2014/12/13 00:36:47 Having a handle to the isolate is equivalent to ha
Lasse Reichstein Nielsen 2014/12/13 02:04:46 Ping does not require any capability, anyone with
+
// Returns true if the capability was added or removed from this isolate's
// list of pause events.
bool AddResumeCapability(const Capability& capability);

Powered by Google App Engine
This is Rietveld 408576698